	`cd "~/Dropbox/VoterID/Replication_Data"

// TABLE 2 and TABLE A2, Summary Statistics //

cap log close
log using "LogFiles/DescriptiveStatsDMV.log", replace

clear all
set more off

use "DataFiles/CombinedDatasetDMV.dta"

// Set min. # of registrants in precinct that must have a block group data
local threshold = .9

gen AboveThreshold = 0
replace AboveThreshold = 1 if prop_registered_precinct > `threshold'
replace AboveThreshold = 0 if nocensusdata == 1
// Drops one case with missing noDMVrecord
sum noDMVrecord
replace AboveThreshold = 0 if noDMVrecord == .

tab AboveThreshold
drop if AboveThreshold == 0

gen sample2 = 1
replace sample2 = 0 if badmatch == 1

label variable noDMVrecord "Share of registrants with no DMV record"
label variable noDMVrecord_filtered "Share of registrants with no DMV record (mailer)"
gen totballots = (TotalVotesSen + totprov - countedprov) / 1000 
label variable totballots "Total ballots cast (1,000s)"
label variable totprov "# of prov. ballots for ID cast"
gen percprov = (totprov / (totballots*1000))*100
label variable percprov "% of ballots provisional for ID"
label variable counted "Share of prov. ballots for ID counted"
gen chgturnout = ln(TotalVotesSen) - ln(TotalVotesGov) if sample2 == 1 
label variable chgturnout "ln(Sen. votes '14) - ln(Gov. votes '13)"

sutex noDMVrecord noDMVrecord_filtered totballots totprov percprov counted chgturnout, /*
*/ file("Tables_and_Figures/DescriptiveStatsDOE.tex") digits(3) minmax labels replace


label variable PercentDemGov "Democratic Gov. vote share '13"

// Actual Registrants

gen age18to24registered = age18_24 / registered_voters
label variable age18to24registered "Share of registrants age 18-24"
gen age65to84registered = age65_84 / registered_voters
label variable age65to84registered "Share of registrants age 65-84"
gen age85upregistered = age85_up / registered_voters 
label variable age85upregistered "Share of registrants age 85+"
gen blackregistered = african_american / registered_voters
label variable blackregistered "Share of registrants black"
gen hispanicregistered = hispanic / registered_voters
label variable hispanicregistered "Share of registrants Hispanic"
gen othernwregistered = (registered_voters - white - african_american - hispanic) / registered_voters
label variable othernwregistered "Share of registrants other nonwhite"

// Census Block Demographics 

gen loghincCB = log(medhincCB)
label variable loghincCB "Logged median income"
gen pnohsdegreerateCB = nohsgradCB / pop25upCB
label variable pnohsdegreerateCB "Share with no high school degree"
gen pcollgradCB = (collgradCB + mastergradCB + profgradCB + docgradCB) / pop25upCB
label variable pcollgradCB "Share with 4-Year college degree"
gen popdensCB = totpopCB / (1000*l_areaCB) 
label variable popdensCB "Population density" 

sutex PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB, /*
*/ file("Tables_and_Figures/DescriptiveStatsDemographics.tex") digits(3) labels minmax replace

log close

// TABLE 3, Provisional Ballot Outcomes //

cap log close
log using "LogFiles/ProvisionalDataTable.log", replace

// Precinct counts of provisional ballots for No ID 
clear all
import excel using "DataFiles/2014 General Election Provisional Ballots3.13.2015.xlsx", sheet(Raw Data)

// Separate by Ballot Type, Absentee vs. Non-Absentee
replace D = "Absentee" if D == "Provisional (Absentee) Ballot Reason Cast"
replace D = "Non-Absentee" if D == "Provisional (Non-Absentee) Ballot Reason Cast" ///
| D == "Provisional(Non-Absentee) Ballot Reason Cast" | D == "NULL"

collapse (sum) F, by(E C D)

gen Accepted = 0 
replace Accepted = F if C == "Counted"

replace E = "Absentee" if D == "Absentee"
replace E = "Other" if E == "NULL"
replace E = "Voter Name Not on Poll Book" if E == ///
"Poll Book (Voter Name is not on Poll Book)" | E == "Non-Registrant"
replace E = "No ID" if E == "No ID (Acceptable Voter ID Not Provided)"
drop D

collapse (sum) F Accepted, by(E)

gen AcceptanceRate = (Accepted/F)*100

replace E = "Absentee Ballot Issue" if E == "Absentee"

order E F Accepted AcceptanceRate

rename E Reason
rename F Number

gsort - Number
// Export Table
ssc install dataout
dataout, save(Tables_and_Figures/ProvisionalBallotTable.tex) tex replace

log close

// TABLE 4, Correlations Between Percent Provisional and Precinct Demographics //
// Must install corrci before running

cap log close
log using "LogFiles/CorrelateDemographicsProvisionals.log", replace

clear all 

use "DataFiles/CombinedDatasetDMV.dta"

// Set min. # of registrants in precinct that must have a block group data
local threshold = .9

gen AboveThreshold = 0
replace AboveThreshold = 1 if prop_registered_precinct > `threshold'
replace AboveThreshold = 0 if nocensusdata == 1
// Drops one case with missing noDMVrecord
sum noDMVrecord
replace AboveThreshold = 0 if noDMVrecord == .

tab AboveThreshold
drop if AboveThreshold == 0

// Sets how many variables are included in table
local variables = 12

matrix correlations = J(3*`variables', 3, -9)

// Calculates the percentage of polling place ballots that were provisionals
gen totprovpercent = (100*totprov) / (TotalVotesSen + totprov - countedprov)
replace totprovpercent = 0 if totprovpercent == .

// Actual Registrants

gen age18to24registered = age18_24 / registered_voters
gen age65to84registered = age65_84 / registered_voters
gen age85upregistered = age85_up / registered_voters 
gen blackregistered = african_american / registered_voters
gen hispanicregistered = hispanic / registered_voters
gen othernwregistered = (registered_voters - white - african_american - hispanic) / registered_voters

corrci totprovpercent noDMVrecord [aweight = totprov + TotalVotesSen]
matrix temp = r(corr)
matrix correlations[1, 1] = temp[2, 1]
matrix temp = r(lb)
matrix correlations[2, 1] = temp[2, 1]
matrix temp = r(ub)
matrix correlations[3, 1] = temp[2, 1]

local i = 7
local column = 1
foreach var of varlist age18to24registered-othernwregistered {
qui corrci totprovpercent `var' [aweight = totprov + TotalVotesSen]
matrix temp = r(corr)
matrix correlations[`i', `column'] = temp[2, 1]
matrix temp = r(lb)
matrix correlations[`i' + 1, `column'] = temp[2, 1]
matrix temp = r(ub)
matrix correlations[`i' + 2, `column'] = temp[2, 1]
local i = `i' + 3
}

// Actual Voted

gen age18to24voted = age18_24_voted / registered_voters_voted
gen age65to84voted = age65_84_voted / registered_voters_voted
gen age85upvoted = age85_up_voted / registered_voters_voted 
gen blackvoted = african_american_voted / registered_voters_voted
gen hispanicvoted = hispanic_voted / registered_voters_voted
gen othernw = (registered_voters_voted - white_voted - african_american_voted - hispanic_voted) / registered_voters_voted

local i = 4
local column = 2
foreach var of varlist PercentDemGov age18to24voted-othernw {
qui corrci totprovpercent `var' [aweight = totprov + TotalVotesSen]
matrix temp = r(corr)
matrix correlations[`i', `column'] = temp[2, 1]
matrix temp = r(lb)
matrix correlations[`i' + 1, `column'] = temp[2, 1]
matrix temp = r(ub)
matrix correlations[`i' + 2, `column'] = temp[2, 1]
local i = `i' + 3
}

// Census Block

egen temp = rsum(a18to24CB-a85andupCB) 
gen page18to24CB = a18to24CB / temp
gen page65to84CB = (a65to74CB + a75to84CB) / temp
gen page85upCB = a85andupCB / temp
drop temp
gen pblackCB= blackCB / totpopCB
gen phispanicCB = hispanicCB / totpopCB
gen pothernwCB = (totpopCB - whiteCB - blackCB - hispanicCB) / totpopCB
gen loghincCB = log(medhincCB)
gen pnohsdegreerateCB = nohsgradCB / pop25upCB
gen pcollgradCB = (collgradCB + mastergradCB + profgradCB + docgradCB) / pop25upCB
gen popdensCB = totpopCB / l_areaCB 

local i = 7
local column = 3
foreach var of varlist page18to24CB-popdensCB {
qui corrci totprovpercent `var' [aweight = totprov + TotalVotesSen]
matrix temp = r(corr)
matrix correlations[`i', `column'] = temp[2, 1]
matrix temp = r(lb)
matrix correlations[`i' + 1, `column'] = temp[2, 1]
matrix temp = r(ub)
matrix correlations[`i' + 2, `column'] = temp[2, 1]
local i = `i' + 3
}

matlist correlations

clear
svmat correlations

forvalues i = 1(1)3 {
gen column`i' = ""
forvalues j = 1(1)`variables' {
local temp1 = round(correlations`i'[1 + (`j' - 1)*3], .001)
local temp2 = round(correlations`i'[2 + (`j' - 1)*3], .001)
local temp3 = round(correlations`i'[3 + (`j' - 1)*3], .001)
local row = 1 + (`j' - 1)*2
replace column`i' = string(`temp1') if _n == `row' & `temp1' ~= -9
replace column`i' = "(" + string(`temp2') + ", " + string(`temp3') + ")" /*
*/ if _n == `row' + 1 & `temp1' ~= -9
}
}
drop correlations*

gen label = "Share of registrants with no DMV record" if _n == 1
replace label = "Democratic Gov. vote share '13" if _n == 3
replace label = "Share of registrants age 18-24" if _n == 5
replace label = "Share of registrants age 65-84" if _n == 7
replace label = "Share of registrants age 85+" if _n == 9
replace label = "Share of registrants black" if _n == 11
replace label = "Share of registrants Hispanic" if _n == 13
replace label = "Share of registrants other nonwhite" if _n == 15
replace label = "Logged median income" if _n == 17
replace label = "Share with no high school degree" if _n == 19
replace label = "Share with 4-Year college degree" if _n == 21
replace label = "Population density" if _n == 23

gen delimit = "&"
drop if _n > 2*`variables'
list label delimit column1 delimit column2 delimit column3, clean 
drop delimit
order label column1 column2 column3
rename label MeasurementLevel
rename column1 PrecinctRegistered
rename column2 PrecinctVoted
rename column3 CensusBlock

dataout, save(Tables_and_Figures/PercentProvCorrelations) tex replace

log close

// TABLE 5 and TABLE A.3, provisional ballot regressions
// Must install estadd before running

cap log close
log using "LogFiles/RegressionsDMVonly.log", replace

clear all 
use "DataFiles/CombinedDatasetDMV.dta"

// Set min. # of registrants in precinct that must have a block group data
local threshold = .9

gen AboveThreshold = 0
replace AboveThreshold = 1 if prop_registered_precinct > `threshold'
replace AboveThreshold = 0 if nocensusdata == 1
// Drops one case with missing noDMVrecord
sum noDMVrecord
replace AboveThreshold = 0 if noDMVrecord == .

tab AboveThreshold
drop if AboveThreshold == 0

label variable noDMVrecord "Share of registrants with no DMV record"
label variable PercentDemGov "Democratic Gov. vote share '13"

gen age18to24registered = age18_24 / registered_voters
label variable age18to24registered "Share of registrants age 18-24"
gen age65to84registered = age65_84 / registered_voters
label variable age65to84registered "Share of registrants age 65-84"
gen age85upregistered = age85_up / registered_voters 
label variable age85upregistered "Share of registrants age 85+"
gen blackregistered = african_american / registered_voters
label variable blackregistered "Share of registrants black"
gen hispanicregistered = hispanic / registered_voters
label variable hispanicregistered "Share of registrants Hispanic"
gen othernwregistered = (registered_voters - white - african_american - hispanic) / registered_voters
label variable othernwregistered "Share of registrants other nonwhite"

// Census Block Demographics 

gen loghincCB = log(medhincCB)
label variable loghincCB "Logged median income"
gen pnohsdegreerateCB = nohsgradCB / pop25upCB
label variable pnohsdegreerateCB "Share with no high school degree"
gen pcollgradCB = (collgradCB + mastergradCB + profgradCB + docgradCB) / pop25upCB
label variable pcollgradCB "Share with 4-Year college degree"
gen popdensCB = totpopCB / (1000*l_areaCB) 
label variable popdensCB "Population density" 

gen totballots = (TotalVotesSen + totprov - countedprov) / 1000 
label variable totballots "Total ballots cast (1,000s)"

zinb totprov noDMVrecord PercentDemGov age18to24registered-totballots, vuong inflate(_cons)
qui{
	nlcom exp([lnalpha]_b[_cons])
	local alpha = exp([lnalpha]_b[_cons])
	mat A=r(V)
	local alpha_se=A[1,1]^0.5
	local inflate = [inflate]_b[_cons]
	local inflate_se = [inflate]_se[_cons]
	local vuong = 1 - normal(e(vuong))
}
outreg2 noDMVrecord PercentDemGov age18to24registered-totballots /*
*/ using "Tables_and_Figures/RegressionsDMVonly.tex", bdec(3) sdec(3)  label /*
*/ adds("Alpha", `alpha', "Alpha SE", `alpha_se', "Inflation Constant", /*
*/ `inflate', "Inflation Constant SE", `inflate_se', "Vuong Test Statistic", /*
*/ e(vuong), "p-value on Vuong Test", `vuong') replace eqdrop(lnalpha)

// check VIF
regress totprov noDMVrecord PercentDemGov age18to24registered-totballots 
estadd vif
matrix temp = e(vif)
matrix vif1 = temp'

// Negative Binomial Regression (full sample)
nbreg totprov noDMVrecord PercentDemGov age18to24registered-totballots 
qui{
	nlcom exp([lnalpha]_b[_cons])
	local alpha = exp([lnalpha]_b[_cons])
	mat A=r(V)
	local alpha_se=A[1,1]^0.5
}
outreg2 noDMVrecord PercentDemGov age18to24registered-totballots /*
*/ using "Tables_and_Figures/RegressionsDMVonly.tex", bdec(3) sdec(3)  label /*
*/ adds("Alpha", `alpha', "Alpha SE", `alpha_se') append eqdrop(lnalpha)

// check VIF
regress totprov noDMVrecord PercentDemGov age18to24registered-totballots
estadd vif
matrix temp = e(vif)
matrix vif2 = temp'

// Negative Binomial Regression with County FE 
// Drops counties where there is only one precinct within that county
// Drops counties where all precincts have totprov = 0
	
gen COUNTYFP = real(substr(CODE, 1, 3))
gen sample = 1
egen numprecinct = sum(prop_registered_precinct > `threshold'), by(COUNTYFP)
replace sample = 0 if numprecinct == 1
egen numposprecinct = sum(totprov > 0), by(COUNTYFP)
replace sample = 0 if numposprecinct == 0
drop numprecinct numposprecinct

// Negative Binomial Regression (county fixed effecs sample)
nbreg totprov noDMVrecord PercentDemGov age18to24registered-totballots if sample == 1
qui{
	nlcom exp([lnalpha]_b[_cons])
	local alpha = exp([lnalpha]_b[_cons])
	mat A=r(V)
	local alpha_se=A[1,1]^0.5
}
outreg2 noDMVrecord PercentDemGov age18to24registered-totballots /*
*/ using "Tables_and_Figures/RegressionsDMVonly.tex", bdec(3) sdec(3)  label /*
*/ adds("Alpha", `alpha', "Alpha SE", `alpha_se') append eqdrop(lnalpha)

// check VIF
regress totprov noDMVrecord PercentDemGov age18to24registered-totballots if sample == 1
estadd vif
matrix temp = e(vif)
matrix vif3 = temp'

// Negative Binomial Regression (county fixed effects)	
nbreg totprov noDMVrecord PercentDemGov age18to24registered-totballots i.COUNTYFP if sample == 1
qui{
	nlcom exp([lnalpha]_b[_cons])
	local alpha = exp([lnalpha]_b[_cons])
	mat A=r(V)
	local alpha_se=A[1,1]^0.5
}
outreg2 noDMVrecord PercentDemGov age18to24registered-totballots /*
*/ using "Tables_and_Figures/RegressionsDMVonly.tex", bdec(3) sdec(3)  label /*
*/ adds("Alpha", `alpha', "", `alpha_se') append eqdrop(lnalpha)

// check VIF
regress totprov noDMVrecord PercentDemGov age18to24registered-totballots i.COUNTYFP if sample == 1
estadd vif
matrix temp = e(vif)
matrix vif4 = temp'

matrix vif = J(13, 4, 0)
forvalues i = 1(1)4 {
forvalues j = 1(1)13 {
matrix vif[`j', `i'] = round(vif`i'[`j', 1], .01)
}
}

ssc install outtable
outtable using "Tables_and_Figures/RegressionsDMVonlyVIF", mat(vif) replace

// Unreported regressions using census block racial data instead of Catalist racial data

gen pblackCB= blackCB / totpopCB
gen phispanicCB = hispanicCB / totpopCB
gen pothernwCB = (totpopCB - whiteCB - blackCB - hispanicCB) / totpopCB

zinb totprov noDMVrecord PercentDemGov age18to24registered-age85upregistered pblackCB /*
*/ phispanicCB pothernwCB loghinc-totballots, vuong inflate(_cons)

nbreg totprov noDMVrecord PercentDemGov age18to24registered-age85upregistered pblackCB /*
*/ phispanicCB pothernwCB loghinc-totballots 

nbreg totprov noDMVrecord PercentDemGov age18to24registered-age85upregistered pblackCB /*
*/ phispanicCB pothernwCB loghinc-totballots if sample == 1

nbreg totprov noDMVrecord PercentDemGov age18to24registered-age85upregistered pblackCB /*
*/ phispanicCB pothernwCB loghinc-totballots i.COUNTYFP if sample == 1 

// FIGURE 3, which calibrates the effect sizes in TABLE 5

cap log close
log using "LogFiles/EffectSize.log", replace

clear all 
use "DataFiles/CombinedDatasetDMV.dta"

// Set min. # of registrants in precinct that must have a block group data
local threshold = .9

gen AboveThreshold = 0
replace AboveThreshold = 1 if prop_registered_precinct > `threshold'
replace AboveThreshold = 0 if nocensusdata == 1
// Drops one case with missing noDMVrecord
sum noDMVrecord
replace AboveThreshold = 0 if noDMVrecord == .

tab AboveThreshold
drop if AboveThreshold == 0

label variable noDMVrecord "Share of registrants with no DMV record"
label variable PercentDemGov "Democratic Gov. vote share '13"

gen age18to24registered = age18_24 / registered_voters
label variable age18to24registered "Share of registrants age 18-24"
gen age65to84registered = age65_84 / registered_voters
label variable age65to84registered "Share of registrants age 65-84"
gen age85upregistered = age85_up / registered_voters 
label variable age85upregistered "Share of registrants age 85+"
gen blackregistered = african_american / registered_voters
label variable blackregistered "Share of registrants black"
gen hispanicregistered = hispanic / registered_voters
label variable hispanicregistered "Share of registrants Hispanic"
gen othernwregistered = (registered_voters - white - african_american - hispanic) / registered_voters
label variable othernwregistered "Share of registrants other nonwhite"

// Census Block Demographics 

gen loghincCB = log(medhincCB)
label variable loghincCB "Logged median income"
gen pnohsdegreerateCB = nohsgradCB / pop25upCB
label variable pnohsdegreerateCB "Share with no high school degree"
gen pcollgradCB = (collgradCB + mastergradCB + profgradCB + docgradCB) / pop25upCB
label variable pcollgradCB "Share with 4-Year college degree"
gen popdensCB = totpopCB / (1000*l_areaCB) 
label variable popdensCB "Population density" 

gen totballots = (TotalVotesSen + totprov - countedprov) / 1000 
label variable totballots "Total ballots cast (1,000s)"

// Negative Binomial Regression (full sample)
nbreg totprov noDMVrecord PercentDemGov age18to24registered-totballots 
margins, atmeans
matrix intercept = r(b)
local intercept = intercept[1, 1] 

matrix estimates = J(13, 3, -9)
local i = 1
foreach var of varlist noDMVrecord PercentDemGov age18to24registered-totballots {
display "`var'"
margins, atmeans dydx(`var') 
matrix coeff = r(b)
matrix variance = r(V)
sum `var'
local std = r(sd)
matrix estimates[`i', 1] = `intercept' + coeff[1, 1] * `std' 
matrix estimates[`i', 2] = `intercept' + (coeff[1, 1] - 1.96*(variance[1, 1]^(1/2))) * `std' 
matrix estimates[`i', 3] = `intercept' + (coeff[1, 1] + 1.96*(variance[1, 1]^(1/2))) * `std' 
local i = `i' + 1
}

matlist estimates
clear 
svmat estimates

gen crap = 14 - _n
label define crap 13 "Share of registrants with no DMV record", replace
label define crap 12 "Democratic Gov. vote share '13", add 
label define crap 11 "Share of registrants age 18-24", add
label define crap 10 "Share of registrants age 65-84", add 
label define crap 9 "Share of registrants age 85+", add 
label define crap 8 "Share of registrants black", add
label define crap 7 "Share of registrants Hispanic", add
label define crap 6 "Share of registrants other nonwhite", add
label define crap 5 "Logged median income", add
label define crap 4 "Share with no high school degree", add
label define crap 3 "Share with 4-Year college degree", add
label define crap 2 "Population density", add
label define crap 1 "Total ballots cast (1,000s)", add

label values crap crap

twoway (scatter crap estimates1, mlcolor(black) mfcolor(white)) /*
*/ (rspike estimates2 estimates3 crap, horizontal lcolor(black)), /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,grid) /*
*/ legend(off) xline(`intercept', lcolor(gray) lpattern(dot) lwidth(thick)) /*
*/ xlabel(0(.05).35) ylabel(1(1)13, valuelabel angle(0)) /*
*/ xtitle("Expected # of Provisional Ballots") ytitle("")

graph export "Tables_and_Figures/EffectSize.eps", replace

// TABLE A4, share of provisional ballots accepted

clear all 
use "DataFiles/CombinedDatasetDMV.dta"

// Set min. # of registrants in precinct that must have a block group data
local threshold = .9

gen AboveThreshold = 0
replace AboveThreshold = 1 if prop_registered_precinct > `threshold'
replace AboveThreshold = 0 if nocensusdata == 1
// Drops one case with missing noDMVrecord
sum noDMVrecord
replace AboveThreshold = 0 if noDMVrecord == .

tab AboveThreshold
drop if AboveThreshold == 0

label variable noDMVrecord "Share of registrants with no DMV record"
label variable PercentDemGov "Democratic Gov. vote share '13"

gen age18to24registered = age18_24 / registered_voters
label variable age18to24registered "Share of registrants age 18-24"
gen age65to84registered = age65_84 / registered_voters
label variable age65to84registered "Share of registrants age 65-84"
gen age85upregistered = age85_up / registered_voters 
label variable age85upregistered "Share of registrants age 85+"
gen blackregistered = african_american / registered_voters
label variable blackregistered "Share of registrants black"
gen hispanicregistered = hispanic / registered_voters
label variable hispanicregistered "Share of registrants Hispanic"
gen othernwregistered = (registered_voters - white - african_american - hispanic) / registered_voters
label variable othernwregistered "Share of registrants other nonwhite"

// Census Block Demographics 

gen loghincCB = log(medhincCB)
label variable loghincCB "Logged median income"
gen pnohsdegreerateCB = nohsgradCB / pop25upCB
label variable pnohsdegreerateCB "Share with no high school degree"
gen pcollgradCB = (collgradCB + mastergradCB + profgradCB + docgradCB) / pop25upCB
label variable pcollgradCB "Share with 4-Year college degree"
gen popdensCB = totpopCB / (1000*l_areaCB) 
label variable popdensCB "Population density" 

gen totballots = (TotalVotesSen + totprov - countedprov) / 1000 
label variable totballots "Total ballots cast (1,000s)"

regress counted noDMVrecord PercentDemGov age18to24registered-totballots [aweight = totprov], robust
outreg2 using "Tables_and_Figures/PercentAcceptedDMVonly.tex", bdec(3) sdec(3)   label replace

log close

// TABLE 6, correlations between change in turnout in 2013 and 2014
// Must install corrci before running

cap log close
log using "LogFiles/CorrelateDemographicsTurnout.log", replace

clear all
set more off

// Set min. # of registrants in precinct that must have a block group data
local threshold = .9
// Sets how many variables are included in table
local variables = 14

matrix correlations = J(3*`variables', 3, -9)

use "DataFiles/CombinedDatasetDMV.dta", clear

gen AboveThreshold = 0
replace AboveThreshold = 1 if prop_registered_precinct > `threshold'
replace AboveThreshold = 0 if nocensusdata == 1
replace AboveThreshold = 0 if badmatch == 1

// Drops one case with missing noDMVrecord
sum noDMVrecord
replace AboveThreshold = 0 if noDMVrecord == .

tab AboveThreshold
drop if AboveThreshold == 0

// Calculates the percent chg in turnout between 2014 and 2013
gen chgturnout = ln(TotalVotesSen) - ln(TotalVotesGov)

// Constructs weighting variable: uses 2013 registrants
gen weighting = all_voters_2013

// Actual Registrants

gen age18to24registered = age18_24 / registered_voters
gen age65to84registered = age65_84 / registered_voters
gen age85upregistered = age85_up / registered_voters 
gen blackregistered = african_american / registered_voters
gen hispanicregistered = hispanic / registered_voters
gen othernwregistered = (registered_voters - white - african_american - hispanic) / registered_voters

corrci chgturnout noDMVrecord [aweight = weighting]
matrix temp = r(corr)
matrix correlations[4, 1] = temp[2, 1]
matrix temp = r(lb)
matrix correlations[5, 1] = temp[2, 1]
matrix temp = r(ub)
matrix correlations[6, 1] = temp[2, 1]

corrci chgturnout noDMVrecord_filtered [aweight = weighting]
matrix temp = r(corr)
matrix correlations[7, 1] = temp[2, 1]
matrix temp = r(lb)
matrix correlations[8, 1] = temp[2, 1]
matrix temp = r(ub)
matrix correlations[9, 1] = temp[2, 1]

local i = 13
local column = 1
foreach var of varlist age18to24registered-othernwregistered {
qui corrci chgturnout `var' [aweight = weighting]
matrix temp = r(corr)
matrix correlations[`i', `column'] = temp[2, 1]
matrix temp = r(lb)
matrix correlations[`i' + 1, `column'] = temp[2, 1]
matrix temp = r(ub)
matrix correlations[`i' + 2, `column'] = temp[2, 1]
local i = `i' + 3
}

// Actual Voted

gen percprov = totprov / (TotalVotesSen + totprov)

corrci chgturnout percprov [aweight = weighting]
matrix temp = r(corr)
matrix correlations[1, 1] = temp[2, 1]
matrix temp = r(lb)
matrix correlations[2, 1] = temp[2, 1]
matrix temp = r(ub)
matrix correlations[3, 1] = temp[2, 1]

gen age18to24voted = age18_24_voted / registered_voters_voted
gen age65to84voted = age65_84_voted / registered_voters_voted
gen age85upvoted = age85_up_voted / registered_voters_voted 
gen blackvoted = african_american_voted / registered_voters_voted
gen hispanicvoted = hispanic_voted / registered_voters_voted
gen othernw = (registered_voters_voted - white_voted - african_american_voted - hispanic_voted) / registered_voters_voted

local i = 10
local column = 2
foreach var of varlist PercentDemGov age18to24voted-othernw {
qui corrci chgturnout `var' [aweight = weighting]
matrix temp = r(corr)
matrix correlations[`i', `column'] = temp[2, 1]
matrix temp = r(lb)
matrix correlations[`i' + 1, `column'] = temp[2, 1]
matrix temp = r(ub)
matrix correlations[`i' + 2, `column'] = temp[2, 1]
local i = `i' + 3
}

// Census Block

egen temp = rsum(a18to24CB-a85andupCB) 
gen page18to24CB = a18to24CB / temp
gen page65to84CB = (a65to74CB + a75to84CB) / temp
gen page85upCB = a85andupCB / temp
drop temp
gen pblackCB= blackCB / totpopCB
gen phispanicCB = hispanicCB / totpopCB
gen pothernwCB = (totpopCB - whiteCB - blackCB - hispanicCB) / totpopCB
gen loghincCB = log(medhincCB)
gen pnohsdegreerateCB = nohsgradCB / pop25upCB
gen pcollgradCB = (collgradCB + mastergradCB + profgradCB + docgradCB) / pop25upCB
gen pcarrateCB = carCB / work16upCB
gen popdensCB = totpopCB / l_areaCB 
replace popdensCB = popdensCB/1000

order pcarrateCB, after(popdensCB)
order noDMVrecord, after(pcarrateCB)

local i = 13
local column = 3
foreach var of varlist page18to24CB-popdensCB {
qui corrci chgturnout `var' [aweight = weighting]
matrix temp = r(corr)
matrix correlations[`i', `column'] = temp[2, 1]
matrix temp = r(lb)
matrix correlations[`i' + 1, `column'] = temp[2, 1]
matrix temp = r(ub)
matrix correlations[`i' + 2, `column'] = temp[2, 1]
local i = `i' + 3
}

// Output Correlations

matlist correlations

clear
svmat correlations

forvalues i = 1(1)3 {
gen column`i' = ""
forvalues j = 1(1)`variables' {
local temp1 = round(correlations`i'[1 + (`j' - 1)*3], .001)
local temp2 = round(correlations`i'[2 + (`j' - 1)*3], .001)
local temp3 = round(correlations`i'[3 + (`j' - 1)*3], .001)
local row = 1 + (`j' - 1)*2
replace column`i' = string(`temp1') if _n == `row' & `temp1' ~= -9
replace column`i' = "(" + string(`temp2') + ", " + string(`temp3') + ")" /*
*/ if _n == `row' + 1 & `temp1' ~= -9
}
}
drop correlations*

gen label = "% Provisional Ballots" if _n == 1
replace label = "% Registrants with No DMV Record" if _n == 3
replace label = "% Registrants with No DMV Record (Mailer)" if _n == 5
replace label = "% Democratic Gov. '13" if _n == 7
replace label = "% Registrants Age 18-24" if _n == 9
replace label = "% Registrants Age 65-84" if _n == 11
replace label = "% Registrants Age 85+" if _n == 13
replace label = "% Registrants Black" if _n == 15
replace label = "% Registrants Hispanic" if _n == 17
replace label = "% Registrants Other Non-White" if _n == 19
replace label = "Logged median income" if _n == 21
replace label = "% No High School Degree" if _n == 23
replace label = "% 4-Year College Degree" if _n == 25
replace label = "Population density" if _n == 27

rename column1 ActualRegistered 
rename column2 ActualVoted
rename column3 CensusBlock

gen delimit = "&"
drop if _n > 2*`variables'
list label delimit ActualRegistered delimit ActualVoted delimit CensusBlock, clean 
drop delimit
order label ActualRegistered ActualVoted CensusBlock

dataout, save(Tables_and_Figures/TurnoutCorrelationTable) tex replace

log close

// TABLE 7, turnout regressions
// TABLE A5, change in regeistered voters regressions
// TABLE A6, VIF from turnout regressions
// Unreported regresion where the racial composition of precinct is measured with census block measures
// Unreported regressions where the dependent variable is change in the share of registered voters who turnout
// Must install estadd before running

cap log close
log using "LogFiles/TurnoutRegressions.log", replace

clear all
set more off

use "DataFiles/CombinedDatasetDMV.dta", clear

// Set min. # of registrants in precinct that must have a block group data
local threshold = .9

gen AboveThreshold = 0
replace AboveThreshold = 1 if prop_registered_precinct > `threshold'
replace AboveThreshold = 0 if nocensusdata == 1
replace AboveThreshold = 0 if badmatch == 1

// Drops one case with missing noDMVrecord
sum noDMVrecord
replace AboveThreshold = 0 if noDMVrecord == .

tab AboveThreshold
drop if AboveThreshold == 0

// Calculates the percent chg in turnout between 2014 and 2013
gen chgturnout = ln(TotalVotesSen) - ln(TotalVotesGov)

// Constructs weighting variable: uses 2013 registrants
gen weighting = all_voters_2013

gen percprov = totprov / (TotalVotesSen + totprov)
label variable percprov "% Provisional Ballots"

label variable noDMVrecord "Share of registrants with no DMV record"
label variable noDMVrecord_filtered "Share of registrants with no DMV record (mailer)"
label variable PercentDemGov "Democratic Gov. vote share '13"

gen age18to24registered = age18_24 / registered_voters
label variable age18to24registered "Share of registrants age 18-24"
gen age65to84registered = age65_84 / registered_voters
label variable age65to84registered "Share of registrants age 65-84"
gen age85upregistered = age85_up / registered_voters 
label variable age85upregistered "Share of registrants age 85+"
gen blackregistered = african_american / registered_voters
label variable blackregistered "Share of registrants black"
gen hispanicregistered = hispanic / registered_voters
label variable hispanicregistered "Share of registrants Hispanic"
gen othernwregistered = (registered_voters - white - african_american - hispanic) / registered_voters
label variable othernwregistered "Share of registrants other nonwhite"

// Census Block Demographics 

gen loghincCB = log(medhincCB)
label variable loghincCB "Logged median income"
gen pnohsdegreerateCB = nohsgradCB / pop25upCB
label variable pnohsdegreerateCB "Share with no high school degree"
gen pcollgradCB = (collgradCB + mastergradCB + profgradCB + docgradCB) / pop25upCB
label variable pcollgradCB "Share with 4-Year college degree"
gen popdensCB = totpopCB / (1000*l_areaCB) 
label variable popdensCB "Population density" 

gen County = real(substr(CODE, 1, 3))

// Turnout Regressions

// Without mailer variable
regress chgturnout percprov noDMVrecord PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB [aweight = weighting]
outreg2 percprov PercentDemGov age18to24registered-othernwregistered /*
*/ loghincCB-popdensCB noDMVrecord using "Tables_and_Figures/TurnoutRegressionDMVonly.tex", bdec(3) sdec(3)  label replace
// check vif 
estadd vif
matrix temp = e(vif)
matrix vif1 = temp'

// Without mailer variable (county fixed effects)
regress chgturnout percprov noDMVrecord PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB  i.County [aweight = weighting]
outreg2 percprov PercentDemGov age18to24registered-othernwregistered /*
*/ loghincCB-popdensCB noDMVrecord using "Tables_and_Figures/TurnoutRegressionDMVonly.tex", bdec(3) sdec(3)  label append
// check vif 
estadd vif
matrix temp = e(vif)
matrix vif2 = temp'

// With mailer variable
regress chgturnout percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB  [aweight = weighting]
test _b[noDMVrecord] + _b[noDMVrecord_filtered] == 0
outreg2 percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-othernwregistered /*
*/ loghincCB-popdensCB using "Tables_and_Figures/TurnoutRegressionDMVonly.tex", bdec(3) sdec(3)  label append
// check vif 
estadd vif
matrix temp = e(vif)
matrix vif3 = temp'

// With mailer variable (county fixed effects)
regress chgturnout percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB  i.County [aweight = weighting]
test _b[noDMVrecord] + _b[noDMVrecord_filtered] == 0
outreg2 percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-othernwregistered /*
*/ loghincCB-popdensCB  using "Tables_and_Figures/TurnoutRegressionDMVonly.tex", bdec(3) sdec(3)  label append
// check vif 
estadd vif
matrix temp = e(vif)
matrix vif4 = temp'

matrix vif = J(14, 4, 0)
forvalues i = 1(1)4 {
forvalues j = 1(1)14 {
matrix vif[`j', `i'] = round(vif`i'[`j', 1], .01)
}
}

ssc install outtable
outtable using "Tables_and_Figures/TurnoutRegressionDMVonlyVIF", mat(vif) replace

// Change in registered voters regressions

// Calculates the change in registered voters between 2014 and 2013
gen chgregvoters = ln(registered_voters) - ln(all_voters_2013)

// Without mailer variable
regress chgregvoters percprov noDMVrecord PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB [aweight = weighting]
outreg2 percprov noDMVrecord PercentDemGov age18to24registered-othernwregistered /*
*/ loghincCB-popdensCB  using "Tables_and_Figures/ChangeRegisteredVotersRegression.tex", bdec(3) sdec(3)  label replace

// Without mailer variable (county fixed effects)
regress chgregvoters percprov noDMVrecord PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB  i.County [aweight = weighting]
outreg2 percprov noDMVrecord PercentDemGov age18to24registered-othernwregistered /*
*/ loghincCB-popdensCB using "Tables_and_Figures/ChangeRegisteredVotersRegression.tex", bdec(3) sdec(3)  label append

// With mailer variable
regress chgregvoters percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB  [aweight = weighting]
test _b[noDMVrecord] + _b[noDMVrecord_filtered] == 0
outreg2 percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-othernwregistered /*
*/ loghincCB-popdensCB using "Tables_and_Figures/ChangeRegisteredVotersRegression.tex", bdec(3) sdec(3)  label append

// With mailer variable (county fixed effects)
regress chgregvoters percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB  i.County [aweight = weighting]
test _b[noDMVrecord] + _b[noDMVrecord_filtered] == 0
outreg2 percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-othernwregistered /*
*/ loghincCB-popdensCB  using "Tables_and_Figures/ChangeRegisteredVotersRegression.tex", bdec(3) sdec(3)  label append

// Unreported regressions using census block racial data instead of Catalist racial data

gen pblackCB= blackCB / totpopCB
gen phispanicCB = hispanicCB / totpopCB
gen pothernwCB = (totpopCB - whiteCB - blackCB - hispanicCB) / totpopCB

regress chgturnout percprov noDMVrecord PercentDemGov age18to24registered-age85upregistered pblackCB-pothernwCB loghincCB-popdensCB  [aweight = weighting]

regress chgturnout percprov noDMVrecord PercentDemGov age18to24registered-age85upregistered pblackCB-pothernwCB loghincCB-popdensCB  i.County [aweight = weighting]

regress chgturnout percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-age85upregistered pblackCB-pothernwCB loghincCB-popdensCB  [aweight = weighting]

regress chgturnout percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-age85upregistered pblackCB-pothernwCB loghincCB-popdensCB i.County [aweight = weighting]

// Unreported regressions using alternative dependent variable specification (change in percent of registered voters who vote)

gen chgturnout2 = TotalVotesSen/registered_voters - TotalVotesGov/all_voters_2013

regress chgturnout2 percprov noDMVrecord PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB  [aweight = weighting]

regress chgturnout2 percprov noDMVrecord PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB i.County [aweight = weighting]

regress chgturnout2 percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB [aweight = weighting]
test _b[noDMVrecord] + _b[noDMVrecord_filtered] == 0

regress chgturnout2 percprov noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-othernwregistered loghincCB-popdensCB i.County [aweight = weighting]
test _b[noDMVrecord] + _b[noDMVrecord_filtered] == 0

log close

// TABLE A7, free photo IDs by precinct

cap log close
log using "LogFiles/FreePhotoID.log", replace

clear all
set more off

use "DataFiles/CombinedDatasetDMV.dta"

// Set min. # of registrants in precinct that must have a block group data
local threshold = .9

gen AboveThreshold = 0
replace AboveThreshold = 1 if prop_registered_precinct > `threshold'
replace AboveThreshold = 0 if nocensusdata == 1

// Drops one case with missing noDMVrecord
sum noDMVrecord
replace AboveThreshold = 0 if noDMVrecord == .

tab AboveThreshold
drop if AboveThreshold == 0

label variable noDMVrecord "Share of registrants with no DMV record"
label variable noDMVrecord_filter "Share of registrants with no DMV record (mailer)"
label variable PercentDemGov "Democratic Gov. vote share '13"

gen age18to24registered = age18_24 / registered_voters
label variable age18to24registered "Share of registrants age 18-24"
gen age65to84registered = age65_84 / registered_voters
label variable age65to84registered "Share of registrants age 65-84"
gen age85upregistered = age85_up / registered_voters 
label variable age85upregistered "Share of registrants age 85+"
gen blackregistered = african_american / registered_voters
label variable blackregistered "Share of registrants black"
gen hispanicregistered = hispanic / registered_voters
label variable hispanicregistered "Share of registrants Hispanic"
gen othernwregistered = (registered_voters - white - african_american - hispanic) / registered_voters
label variable othernwregistered "Share of registrants other nonwhite"

// Census Block Demographics 

gen loghincCB = log(medhincCB)
label variable loghincCB "Logged median income"
gen pnohsdegreerateCB = nohsgradCB / pop25upCB
label variable pnohsdegreerateCB "Share with no high school degree"
gen pcollgradCB = (collgradCB + mastergradCB + profgradCB + docgradCB) / pop25upCB
label variable pcollgradCB "Share with 4-Year college degree"
gen popdensCB = totpopCB / (1000*l_areaCB) 
label variable popdensCB "Population density" 

gen totregistered = all_voters_2013 / 1000 
label variable totregistered "Registered Voters in 2013 (thousands)"

gen County = real(substr(CODE, 1, 3))

nbreg free_id noDMVrecord totregistered i.County  
qui{
	nlcom exp([lnalpha]_b[_cons])
	local alpha = exp([lnalpha]_b[_cons])
	mat A=r(V)
	local alpha_se=A[1,1]^0.5
}
outreg2 noDMVrecord totregistered /*
*/ using "Tables_and_Figures/FreePhotoID.tex", bdec(3) sdec(3)  label/*
*/ adds("Alpha", `alpha', "", `alpha_se') replace eqdrop(lnalpha)

nbreg free_id noDMVrecord noDMVrecord_filtered totregistered i.County
qui{
	nlcom exp([lnalpha]_b[_cons])
	local alpha = exp([lnalpha]_b[_cons])
	mat A=r(V)
	local alpha_se=A[1,1]^0.5
}
outreg2 noDMVrecord noDMVrecord_filtered totregistered /*
*/ using "Tables_and_Figures/FreePhotoID.tex", bdec(3) sdec(3)  label /*
*/ adds("Alpha", `alpha', "", `alpha_se') append eqdrop(lnalpha)
test _b[noDMVrecord] + _b[noDMVrecord_filtered] == 0

nbreg free_id noDMVrecord PercentDemGov age18to24registered-popdensCB totregistered i.County
qui{
	nlcom exp([lnalpha]_b[_cons])
	local alpha = exp([lnalpha]_b[_cons])
	mat A=r(V)
	local alpha_se=A[1,1]^0.5
}
outreg2 noDMVrecord PercentDemGov age18to24registered-popdensCB totregistered /*
*/ using "Tables_and_Figures/FreePhotoID.tex", bdec(3) sdec(3)  label /*
*/ adds("Alpha", `alpha', "", `alpha_se') append eqdrop(lnalpha)


nbreg free_id noDMVrecord noDMVrecord_filtered PercentDemGov age18to24registered-popdensCB totregistered i.County
qui{
	nlcom exp([lnalpha]_b[_cons])
	local alpha = exp([lnalpha]_b[_cons])
	mat A=r(V)
	local alpha_se=A[1,1]^0.5
}
test _b[noDMVrecord] + _b[noDMVrecord_filtered] == 0
outreg2 noDMVrecord PercentDemGov age18to24registered-popdensCB  totregistered  /*
*/ using "Tables_and_Figures/FreePhotoID.tex", bdec(3) sdec(3)  label /*
*/ adds("Alpha", `alpha', "", `alpha_se') append eqdrop(lnalpha)

log close


// FIGURE A.1, General Election Votes vs. Catalist Votes //
// FIGURE A.2, General Election Votes vs. Catalist Votes, Richmond City //
// FIGURE A.3, General Election Votes vs. Catalist Votes, excluding Richmond City //
// FIGURE A.4, General Election Votes vs. Number of Registered Voters, Richmond City  //

cap log close
log using "LogFiles/CompareCatalistElectionData.log", replace

clear all
set more off

use "DataFiles/CombinedDatasetDMV.dta"

// Compare # of vote records in Catalist data to the actual number of senate votes
regress registered_voters_voted TotalVotesSen
local r2 = round(e(r2), .001)
twoway (scatter registered_voters_voted TotalVotesSen, mlcolor(gray) mfcolor(white)) /*
*/ (lfit registered_voters_voted TotalVotesSen, lcolor(black)), /*
*/ ytitle("# of Vote Records in Catalist") xtitle("# of Total Senate Votes") /*
*/ legend(lab(1 "Obs.") lab(2 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/CatalistElectionDataAll.eps", replace

// Checks if all severe outliers are in Richmond City (760)
gen countynum = substr(CODE, 1, 3)
regress registered_voters_voted TotalVotesSen if countynum ~= "760"
local r2 = round(e(r2), .001)
twoway (scatter registered_voters_voted TotalVotesSen if countynum ~= "760", mlcolor(gray) mfcolor(white)) /*
*/ (lfit registered_voters_voted TotalVotesSen if countynum ~= "760", lcolor(black)), /*
*/ ytitle("# of Vote Records in Catalist") xtitle("# of Total Senate Votes") /*
*/ legend(lab(1 "Obs.") lab(2 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/CatalistElectionDataNoRichmond.eps", replace

regress registered_voters_voted TotalVotesSen if countynum == "760"
local r2 = round(e(r2), .001)
twoway (scatter registered_voters_voted TotalVotesSen if countynum == "760", mlcolor(gray) mfcolor(white)) /*
*/ (lfit registered_voters_voted TotalVotesSen if countynum == "760", lcolor(black)), /*
*/ ytitle("# of Vote Records in Catalist") xtitle("# of Total Senate Votes") /*
*/ legend(lab(1 "Obs.") lab(2 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/CatalistElectionDataRichmond.eps", replace

// Looks at registered voters in Richmond City
// Highlight precincts with at least 100 fewer votes in Catalist than Senate votes
regress registered_voters TotalVotesSen if countynum == "760"
local r2 = round(e(r2), .001)
twoway (scatter registered_voters TotalVotesSen if countynum == "760" & (TotalVotesSen - registered_voters_voted) > 100, mcolor(gray)) /*
*/ (scatter registered_voters TotalVotesSen if countynum == "760" & (TotalVotesSen - registered_voters_voted) < 100, mlcolor(gray) mfcolor(white)) /*
*/ (lfit registered_voters TotalVotesSen), /*
*/ ytitle("Registered Records in Catalist") xtitle("# of Total Senate Votes") /*
*/ legend(lab(1 "Bad Catalist Data")  lab(2 "Normal Catalist Data") lab(3 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/CatalistElectionDataRichmondRegistered.eps", replace

log close


// FIGURE A.5,  Cumulative Distribution Function //
// FIGURE A.6,  Age 18-24 Validation //
// FIGURE A.7,  Age 65-84 Validation  //
// FIGURE A.8,  Age 85+ Validation //
// FIGURE A.9,  Percent Black Validation //
// FIGURE A.10, Percent Hispanic Validation //
// FIGURE A.11, Percent Other Non-White Validation  //

cap log close
log using "LogFiles/Validation.log", replace

clear all
set more off

// Set min. # of registrants in precinct that must have a block group data
local threshold = .9

use "DataFiles/CombinedDatasetDMV.dta"

drop if nocensusdata == 1
// Drops one case with missing noDMVrecord
sum noDMVrecord
drop if noDMVrecord == .


// Cumulative Distribution Function //
sort prop_registered_precinct
cumul prop_registered_precinct, gen(cdf)
line cdf prop_registered_precinct, xline(0.9, lpattern(dash) lcolor(black)) /*
*/ ytitle(Cumulative Probability) xtitle(% of Precinct's Registered Voters with Corresponding Block Group Data) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid)
graph export "Tables_and_Figures/CumulativeDistributionFunction.eps", replace


// Actual Registrants

gen age18to24registered = age18_24 / registered_voters
gen age65to84registered = age65_84 / registered_voters
gen age85upregistered = age85_up / registered_voters 
gen blackregistered = african_american / registered_voters
gen hispanicregistered = hispanic / registered_voters
gen othernwregistered = (registered_voters - white - african_american - hispanic) / registered_voters

// Census Block

egen temp = rsum(a18to24CB-a85andupCB) 
gen page18to24CB = a18to24CB / temp
gen page65to84CB = (a65to74CB + a75to84CB) / temp
gen page85upCB = a85andupCB / temp
drop temp
gen pblackCB = blackCB / totpopCB
gen phispanicCB = hispanicCB / totpopCB
gen pothernwCB = (totpopCB - whiteCB - blackCB - hispanicCB) / totpopCB


regress age18to24registered page18to24CB if prop_registered_precinct > `threshold'
local r2=round(e(r2), .001)
twoway (scatter age18to24registered page18to24CB, mlcolor(gray) mfcolor(white)) /*
*/ (lfit age18to24registered page18to24CB, lcolor(black)) /*
*/ if nocensusdata == 0 & prop_registered_precinct > `threshold',  /*
*/ ytitle("% 18 - 24, Catalist (Registered)") xtitle("% 18 - 24, ACS") /*
*/ legend(lab(1 "Precinct") lab(2 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/ValidateAge1824.eps", replace

regress age65to84registered page65to84CB if prop_registered_precinct > `threshold'
local r2=round(e(r2), .001)
twoway (scatter age65to84registered page65to84CB, mlcolor(gray) mfcolor(white)) /*
*/ (lfit age65to84registered page65to84CB, lcolor(black)) /*
*/ if nocensusdata == 0 & prop_registered_precinct > `threshold', /*
*/ ytitle("% 65 - 84, Catalist (Registered)") xtitle("% 65 - 84, ACS") /*
*/ legend(lab(1 "Precinct") lab(2 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/ValidateAge6584.eps", replace

regress age85upregistered page85upCB if prop_registered_precinct > `threshold'
local r2=round(e(r2), .001)
twoway (scatter age85upregistered page85upCB, mlcolor(gray) mfcolor(white)) /*
*/ (lfit age85upregistered page85upCB, lcolor(black))/*
*/ if nocensusdata == 0 & prop_registered_precinct > `threshold', /*
*/ ytitle("% 85+, Catalist (Registered)") xtitle("% 85+, ACS") /*
*/ legend(lab(1 "Precinct") lab(2 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/ValidateAge85up.eps", replace

regress blackregistered pblackCB if prop_registered_precinct > `threshold'
local r2=round(e(r2), .001)
twoway (scatter blackregistered pblackCB, mlcolor(gray) mfcolor(white)) /*
*/ (lfit blackregistered pblackCB, lcolor(black)) /*
*/ if nocensusdata == 0 & prop_registered_precinct > `threshold',  /*
*/ ytitle("% Black, Catalist (Registered)") xtitle("% Black, ACS") /*
*/ legend(lab(1 "Precinct") lab(2 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/ValidateBlack.eps", replace

regress hispanicregistered phispanicCB if prop_registered_precinct > `threshold'
local r2=round(e(r2), .001)
twoway (scatter hispanicregistered phispanicCB, mlcolor(gray) mfcolor(white)) /*
*/ (lfit hispanicregistered phispanicCB, lcolor(black)) /*
*/ if nocensusdata == 0 & prop_registered_precinct > `threshold',  /*
*/ ytitle("% Hispanic, Catalist (Registered)") xtitle("% Hispanic, ACS") /*
*/ legend(lab(1 "Precinct") lab(2 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/ValidateHispanic.eps", replace

regress othernwregistered pothernwCB if prop_registered_precinct > `threshold'
local r2=round(e(r2), .001)
twoway (scatter othernwregistered pothernwCB, mlcolor(gray) mfcolor(white)) /*
*/ (lfit othernwregistered pothernwCB, lcolor(black)) /*
*/ if nocensusdata == 0 & prop_registered_precinct > `threshold',  /*
*/ ytitle("% Other Non-White, Catalist (Registered)") xtitle("% Other Non-White, ACS") /*
*/ legend(lab(1 "Precinct") lab(2 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/ValidateOtherNW.eps", replace

log close

// FIGURE A.12, Scatter 2013 and 2014 Turnout // 

cap log close
log using "LogFiles/TurnoutScatter.log", replace

// Set min. # of registrants in precinct that must have a block group data
local threshold = .9

use "DataFiles/CombinedDatasetDMV.dta", clear

gen AboveThreshold = 0
replace AboveThreshold = 1 if prop_registered_precinct > `threshold'
replace AboveThreshold = 0 if nocensusdata == 1
replace AboveThreshold = 0 if badmatch == 1

// Drops one case with missing noDMVrecord
sum noDMVrecord
replace AboveThreshold = 0 if noDMVrecord == .

tab AboveThreshold
drop if AboveThreshold == 0

regress TotalVotesSen TotalVotesGov 
local r2=round(e(r2), .001)
twoway (scatter TotalVotesSen TotalVotesGov, mlcolor(gray) mfcolor(white)) /*
*/ (lfit TotalVotesSen TotalVotesGov, lcolor(black)),  /*
*/ ytitle("Total Senate Votes, 2014") xtitle("Total Governor Votes, 2013") /*
*/ legend(lab(1 "Precinct") lab(2 "Linear Fit")) /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) note(R-squared=`r2') 
graph export "Tables_and_Figures/TurnoutChangeScatter.eps", replace

log close
